arxiv.integration.kinesis.consumer.tests module
===============================================

.. automodule:: arxiv.integration.kinesis.consumer.tests
    :members:
    :undoc-members:
    :show-inheritance:
